@@ -3,9 +3,10 @@
 
 import dateutil.parser
 import logging
-from requests import HTTPError
+import sys
 
 from bits.github import GitHub
+from requests import HTTPError
 
 
 class Update(object):
@@ -17,8 +18,8 @@ class Update(object):
         self.github = github
 
         self.verbose = False
-        if self.github:
-            self.verbose = self.github.verbose
+        if self.auth:
+            self.verbose = self.auth.verbose
 
         # data
         self.github_ids = {}
@@ -120,18 +121,40 @@ class Update(object):
 
     def _get_users(self):
         """Return a dict of users."""
-        datastore = self.github.datastore()
-        self.users = datastore.get_users_dict()
-
+        firestore = self.github.firestore(app_project='broad-github-app')
         # get users by github_id and google_id
         self.github_ids = {}
         self.google_ids = {}
-        for email in self.users:
-            e = self.users[email]
-            github_id = e['github_id']
-            google_id = e['google_id']
-            self.github_ids[github_id] = e
-            self.google_ids[google_id] = e
+        self.users = {}
+        for t in firestore.get_tokens():
+            email = t['google_email']
+            t['github_id'] = str(t['github_id'])
+            t['google_id'] = str(t['google_id'])
+            github_id = t['github_id']
+            google_id = t['google_id']
+
+            # fix login
+            t['login'] = t['github_login'].lower()
+            del t['github_login']
+
+            self.github_ids[github_id] = t
+            self.google_ids[google_id] = t
+            self.users[email] = t
+
+            # import json
+            # print(json.dumps(t, indent=2, sort_keys=True, default=str))
+
+        # datastore = self.github.datastore()
+        # self.users = datastore.get_users_dict()
+        # # get users by github_id and google_id
+        # self.github_ids = {}
+        # self.google_ids = {}
+        # for email in self.users:
+        #     e = self.users[email]
+        #     github_id = e['github_id']
+        #     google_id = e['google_id']
+        #     self.github_ids[github_id] = e
+        #     self.google_ids[google_id] = e
 
         return self.users
 
@@ -231,7 +254,7 @@ class Update(object):
         return team_members
 
     #
-    # Update Team Members
+    # Update Org Members
     #
     def update_members(self):
         """Update members in GitHub."""
@@ -274,7 +297,7 @@ class Update(object):
             print('Done updating GitHub members.')
 
     #
-    # Update Teams
+    # Update Org Teams
     #
     def update_team(self, slug, team_id, email):
         """Update a single team."""
@@ -368,6 +391,13 @@ class Update(object):
     #
     def update_team_syncs(self):
         """Update Team Syncs from On-Prem Mongo to Cloud Firestore."""
+        b = self.auth.bitsdbapi()
+
+        firestore_project = self.auth.settings.get('githubapp', {}).get('project')
+        if not firestore_project:
+            logging.error('Firestore Project required: settings["githubapp"]["project]')
+            sys.exit()
+
         g = self.auth.google()
         g.auth_service_account(g.scopes, g.subject)
 
@@ -376,8 +406,9 @@ class Update(object):
         mongo_team_syncs = m.get_collection('github_team_sync')
         print('Found {} GitHub Team Syncs in BITSdb Mongo.'.format(len(mongo_team_syncs)))
 
-        # create new dict of team syncs ready for firestore
-        team_syncs = {}
+        # create new dict of team syncs ready for datastore and firestore
+        datastore_syncs = {}
+        firestore_syncs = {}
         for sync in sorted(mongo_team_syncs, key=lambda x: x['google_group']):
             del sync['_id']
             email = sync['google_group']
@@ -390,7 +421,20 @@ class Update(object):
             for m in g.directory().get_members_recursively(email):
                 members.append(m['id'])
 
-            new_sync = {
+            # prepare sync for datastore (bitsdb api)
+            datastore_sync = {
+                'kind': 'github#teamsync',
+                'id': str(sync['github_team']),
+                'google_group_id': group['id'],
+                'google_group_email': group['email'],
+                'google_group_name': group['name'],
+                'github_team_id': str(sync['github_team']),
+                'github_team_name': sync['github_team_name'],
+                'github_team_slug': sync['github_team_slug'],
+            }
+
+            # prepare sync for firestore (github app)
+            firestore_sync = {
                 # sync info
                 'created': sync['created'],
                 'modified': sync['modified'],
@@ -405,18 +449,36 @@ class Update(object):
                 'team_slug': sync['github_team_slug'],
             }
             team_id = str(sync['github_team'])
-            if team_id in team_syncs:
-                print('Duplicate Sync: {} -> {}'.format(email, team_id))
-            team_syncs[team_id] = new_sync
 
-        # get current team syncs from destination - broad-github-app firestore
-        projects = ['broad-github-app', 'broad-github-app-dev']
-        for project in projects:
-            print(g.firestore(project).update_collection_batch(
-                'team_syncs',
-                team_syncs,
-                delete_docs=True,
-            ))
+            # add to datastore syncs
+            if team_id in datastore_syncs:
+                print('Duplicate Datastore Sync: {} -> {}'.format(email, team_id))
+            datastore_syncs[team_id] = datastore_sync
+
+            # add to firestore syncs
+            if team_id in firestore_syncs:
+                print('Duplicate Firestore Sync: {} -> {}'.format(email, team_id))
+            firestore_syncs[team_id] = firestore_sync
+
+        # update the data in the bitsdb api
+        b.update(
+            cls=g,
+            collection='github/teams/syncs',
+            data=datastore_syncs,
+            delete_function='delete_github_team_sync',
+            insert_function='add_github_team_sync',
+            list_function='get_github_team_syncs',
+            key='github_team_id',
+            kinds='teams_syncs',
+            prep=False,
+        )
+
+        # update firestore in the github app projects
+        print(g.firestore(firestore_project).update_collection_batch(
+            'team_syncs',
+            firestore_syncs,
+            delete_docs=True,
+        ))
 
     #
     # Update Users
